#ifndef ENGINE_H_INCLUDED
#define ENGINE_H_INCLUDED

unsigned long long engine_time;

int engine_init();

int engine_set_mode(unsigned width, unsigned height, char depth, char fullscreen_flag);

int engine_set_title(char *title);

void engine_set_icon(unsigned long *icon_data, int icon_data_length);

void engine_set_drawing_function(void (*drawing_function)());

void engine_set_keys_handler
	(void (*keys_handler)(unsigned keycode, int x, int y, char state_flag));

void engine_set_motion_handler(void (*motion_handler)(int x, int y));

void engine_set_focus_handler(void (*focus_handler)(char state));

void engine_set_max_fps(float max_fps);

void engine_main_loop();

void engine_free();

enum engine_return_codes
{
	engine_ec_ok = 0,
	engine_ec_error,
	engine_ec_bad_depth,
	engine_ec_window_size_too_big,
	engine_ec_window_already_created
};

enum engine_state_codes
{
	engine_sc_key_down = 0,
	engine_sc_key_up
};

enum engine_focus_states
{
	engine_fs_focus_out = 0,
	engine_fs_focus_in,
	engine_fs_pointer_leave,
	engine_fs_pointer_enter
};

enum engine_keys_codes
{
	engine_kc_mouse1 = 1,
	engine_kc_mouse2,
	engine_kc_mouse3,
	engine_kc_mwheelup,
	engine_kc_mwheeldown,
	engine_kc_esc = 9,
	engine_kc_1,
	engine_kc_2,
	engine_kc_3,
	engine_kc_4,
	engine_kc_5,
	engine_kc_6,
	engine_kc_7,
	engine_kc_8,
	engine_kc_9,
	engine_kc_0,
	engine_kc_minus,
	engine_kc_equal,
	engine_kc_backspace,
	engine_kc_tab,
	engine_kc_q,
	engine_kc_w,
	engine_kc_e,
	engine_kc_r,
	engine_kc_t,
	engine_kc_y,
	engine_kc_u,
	engine_kc_i,
	engine_kc_o,
	engine_kc_p,
	engine_kc_left_brocket,
	engine_kc_right_brocket,
	engine_kc_enter,
	engine_kc_lctrl,
	engine_kc_a,
	engine_kc_s,
	engine_kc_d,
	engine_kc_f,
	engine_kc_g,
	engine_kc_h,
	engine_kc_j,
	engine_kc_k,
	engine_kc_l,
	engine_kc_semicolon,
	engine_kc_apostrophe,
	engine_kc_backtick,
	engine_kc_lshift,
	engine_kc_backslash,
	engine_kc_z,
	engine_kc_x,
	engine_kc_c,
	engine_kc_v,
	engine_kc_b,
	engine_kc_n,
	engine_kc_m,
	engine_kc_comma,
	engine_kc_point,
	engine_kc_slash,
	engine_kc_rshift,
	engine_kc_numasterisk,
	engine_kc_lalt,
	engine_kc_space,
	engine_kc_caps_lock,
	engine_kc_f1,
	engine_kc_f2,
	engine_kc_f3,
	engine_kc_f4,
	engine_kc_f5,
	engine_kc_f6,
	engine_kc_f7,
	engine_kc_f8,
	engine_kc_f9,
	engine_kc_f10,
	engine_kc_num_lock,
	engine_kc_scroll_lock,
	engine_kc_num7,
	engine_kc_num8,
	engine_kc_num9,
	engine_kc_numminus,
	engine_kc_num4,
	engine_kc_num5,
	engine_kc_num6,
	engine_kc_numplus,
	engine_kc_num1,
	engine_kc_num2,
	engine_kc_num3,
	engine_kc_num0,
	engine_kc_numpoint,
	engine_kc_f11 = 95,
	engine_kc_f12,
	engine_kc_home,
	engine_kc_up,
	engine_kc_page_up,
	engine_kc_left,
	engine_kc_right = 102,
	engine_kc_end,
	engine_kc_down,
	engine_kc_page_down,
	engine_kc_insert,
	engine_kc_delete,
	engine_kc_numenter,
	engine_kc_rctrl,
	engine_kc_pause,
	engine_kc_print_screen,
	engine_kc_numslash,
	engine_kc_ralt,
	engine_kc_lwin = 115,
	engine_kc_rwin,
	engine_kc_menu
};

extern char *engine_keys_names[];
extern unsigned engine_keys_names_number;
extern char engine_keys_states[];

#endif /* ENGINE_H_INCLUDED */
